import pycountry
from gadm import GADMDownloader
import geopandas as gpd


def search_country_by_keyword(keyword: str):
    return pycountry.countries.search_fuzzy(keyword)


def get_country_admin_boundaries(country_name: str, ad_level: int) -> gpd.GeoDataFrame:
    """Wrapper of GADM function to get admin boundaries of a country.

    Can use country ISO code or country name.
    Can use `search_country_by_keyword` to get the country name or ISO code."""
    downloader = GADMDownloader(version="4.0")
    gdf = downloader.get_shape_data_by_country_name(country_name=country_name, ad_level=ad_level)
    assert isinstance(gdf, gpd.GeoDataFrame)
    assert gdf.crs == "EPSG:4326"
    return gdf



from setuptools import setup, find_packages

setup(
    name="disruptsc-dataprep",
    version="1.0.0",
    description="Tools to help prepare data for the DisruptSC model.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="Celian Colon",
    author_email="celian.colon.2007@polytechnique.org",
    url="https://github.com/ccolon/disruptsc-dataprep",
    packages=find_packages(),
    license="CC BY-NC-ND 4.0",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: Other/Proprietary License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.10",
    install_requires=[
        "gadm==0.0.5"
    ],
)
